summaryrefslogtreecommitdiffstats
path: root/chrome/browser/ui/panels/panel.h
diff options
context:
space:
mode:
authorjam@chromium.org <jam@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2012-01-03 05:53:20 +0000
committerjam@chromium.org <jam@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2012-01-03 05:53:20 +0000
commit4ca153033f022dc6e11d6094daed41b1ed0a995f (patch)
treef4720517b10953166f84707ca3ec8b82de860884 /chrome/browser/ui/panels/panel.h
parent08bd3d71d969061b1588e6a4210f6d74b0ec0c6d (diff)
downloadchromium_src-4ca153033f022dc6e11d6094daed41b1ed0a995f.zip
chromium_src-4ca153033f022dc6e11d6094daed41b1ed0a995f.tar.gz
chromium_src-4ca153033f022dc6e11d6094daed41b1ed0a995f.tar.bz2
Replace most of Browser::GetSelectedTabContents calls into Browser::GetSelectedWebContents. I've converted the easy ones, I'll do the ones with more dependencies in a separate change to keep things trivial to review.
I considered taking out GetSelectedTabContents altogether and having people just use GetSelectedTabContentsWrapper()->web_contents() per the existing comment in browser.h, but there are a lot of callers and it seemed too long to type. BUG=98716 TBR=joi Review URL: http://codereview.chromium.org/9015022 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@116122 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/browser/ui/panels/panel.h')
-rw-r--r--chrome/browser/ui/panels/panel.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/chrome/browser/ui/panels/panel.h b/chrome/browser/ui/panels/panel.h
index af3f0d3..61b54cf 100644
--- a/chrome/browser/ui/panels/panel.h
+++ b/chrome/browser/ui/panels/panel.h
@@ -272,12 +272,12 @@ class Panel : public BrowserWindow,
// size may differ after panel layout.
Panel(Browser* browser, const gfx::Size& requested_size);
// Configures the tab contents for auto resize, including configurations
// on the renderer and detecting renderer changes.
- void EnableTabContentsAutoResize(TabContents* tab_contents);
+ void EnableWebContentsAutoResize(content::WebContents* web_contents);
// Configures the renderer for auto resize (if auto resize is enabled).
- void ConfigureAutoResize(TabContents* tab_contents);
+ void ConfigureAutoResize(content::WebContents* web_contents);
Browser* browser_; // Weak, owned by native panel.
@@ -272,12 +272,12 @@ class Panel : public BrowserWindow,
// size may differ after panel layout.
Panel(Browser* browser, const gfx::Size& requested_size);
- // Configures the tab contents for auto resize, including configurations
+ // Configures the web contents for auto resize, including configurations
// on the renderer and detecting renderer changes.